.. include:: ../README.rst

.. include:: reading.rst

.. include:: img2ts.rst

Contents
========

.. toctree::
   :maxdepth: 2

   Reading <reading>
   Variable names <varnames>
   Conversion to time series <img2ts>
   License <license>
   Authors <authors>
   Changelog <changes>
   Module Reference <api/modules>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
